.. Use python as the default language for syntax highlighting in this file
.. highlight:: python

.. _boutpp_api:

.. default-domain:: py

boutpp package
================

Module contents
---------------

.. automodule:: boutpp
    :members:

Undocumented functions
----------------------

.. automodule:: boutpp
   :undoc-members:

Special and inherited functions
-------------------------------

.. automodule:: boutpp
   :special-members:
   :inherited-members:
